pydns
------
Simple Python DNS Library. DNS Packet-Parsing/Client/Server

### Installation

```
pip install pydns3
```

### Examples

Examples can be found in the [examples](https://github.com/imgurbot12/pydns/tree/master/examples) directory.
